@@ -6,19 +6,21 @@ sudo apt-get install -y \
     libcapture-tiny-perl \
     libcarp-assert-perl \
     libclone-perl \
+    libdate-calc-perl \
+    libdatetime-format-rfc3339-perl \
     libdbd-mysql-perl \
     libdbd-sqlite3-perl \
     libdbi-perl \
     libdigest-sha-perl \
     libhtml-parser-perl \
     libjson-perl \
-    libxml-simple-perl \
     liblist-moreutils-perl \
+    libchemistry-openbabel-perl \
     libparse-yapp-perl \
     libwww-curl-perl \
+    libxml-simple-perl \
     openbabel \
     perl \
     python-argparse \
-    sqlite3 \
     tree \
 ;
