@@ -6,6 +6,8 @@ sudo apt-get install -y \
     libcapture-tiny-perl \
     libcarp-assert-perl \
     libclone-perl \
+    libdate-calc-perl \
+    libdatetime-format-rfc3339-perl \
     libdbd-mysql-perl \
     libdbd-sqlite3-perl \
     libdbi-perl \
@@ -13,11 +15,11 @@ sudo apt-get install -y \
     libhtml-parser-perl \
     libjson-perl \
     liblist-moreutils-perl \
+    libchemistry-openbabel-perl \
     libparse-yapp-perl \
     libwww-curl-perl \
     libxml-simple-perl \
     openbabel \
     perl \
     python-argparse \
-    sqlite3 \
     tree
