@@ -1,8 +1,8 @@
 /*---------------------------------------------------------------------------*\
 **$Author: andrius $
-**$Date: 2017-06-02 11:20:51 +0300 (Fri, 02 Jun 2017) $
-**$Revision: 5405 $
-**$URL: svn://www.crystallography.net/cod-tools/tags/v2.1/src/components/codcif/cif2_lexer.c $
+**$Date: 2017-11-07 11:53:10 +0200 (Tue, 07 Nov 2017) $
+**$Revision: 5724 $
+**$URL: svn://www.crystallography.net/cod-tools/tags/v2.2/src/components/codcif/cif2_lexer.c $
 \*---------------------------------------------------------------------------*/
 
 /* exports: */
@@ -21,8 +21,6 @@
 #include <stringx.h>
 #include <assert.h>
 
-FILE *yyin;
-
 static CIF_COMPILER *cif_cc;
 
 static char *current_line;
@@ -99,9 +97,9 @@ static int cif_lexer( FILE *in, cexception_t *ex );
 
 int cif2lex( void )
 {
-    if( !yyin )
-        yyin = stdin;
-    return cif_lexer( yyin, NULL );
+    if( !cif_compiler_file( cif_cc ) )
+        cif_compiler_set_file( cif_cc, stdin );
+    return cif_lexer( cif_compiler_file( cif_cc ), NULL );
 }
 
 void cif2restart( void )
@@ -595,7 +593,7 @@ static void pushchar( char **buf, size_t *length, size_t pos, int ch )
         }
         *length *= 2;
         if( yy_flex_debug ) {
-            printf( ">>> reallocating lex token buffer to %d\n", *length );
+            printf( ">>> reallocating lex token buffer to %lu\n", *length );
         }
         *buf = reallocx( *buf, *length, NULL );
     }
