@@ -1,8 +1,8 @@
 /*---------------------------------------------------------------------------*\
 **$Author: andrius $
-**$Date: 2017-08-04 15:35:04 +0300 (Fri, 04 Aug 2017) $
-**$Revision: 5490 $
-**$URL: svn://www.crystallography.net/cod-tools/tags/v2.1/src/components/codcif/cif_lexer.c $
+**$Date: 2018-01-19 11:56:34 +0200 (Fri, 19 Jan 2018) $
+**$Revision: 5955 $
+**$URL: svn://www.crystallography.net/cod-tools/tags/v2.2/src/components/codcif/cif_lexer.c $
 \*---------------------------------------------------------------------------*/
 
 /* exports: */
@@ -21,8 +21,6 @@
 #include <stringx.h>
 #include <assert.h>
 
-FILE *yyin;
-
 static CIF_COMPILER *cif_cc;
 
 static char *current_line;
@@ -96,9 +94,9 @@ static int cif_lexer( FILE *in, cexception_t *ex );
 
 int ciflex( void )
 {
-    if( !yyin )
-        yyin = stdin;
-    return cif_lexer( yyin, NULL );
+    if( !cif_compiler_file( cif_cc ) )
+        cif_compiler_set_file( cif_cc, stdin );
+    return cif_lexer( cif_compiler_file( cif_cc ), NULL );
 }
 
 void cifrestart( void )
@@ -145,7 +143,7 @@ static int cif_lexer( FILE *in, cexception_t *ex )
                                  cif_flex_previous_line_number(), -1, ex );
             } else {
                 ciferror( "DOS EOF symbol ^Z was encountered, "
-                         "it is not permitted in CIFs" );
+                          "it is not permitted in CIFs" );
             }
             prevchar = ch;
             ch = getlinec( in, ex );
@@ -164,8 +162,15 @@ static int cif_lexer( FILE *in, cexception_t *ex )
                     putchar( ch );
                 }
                 if( (ch < 32 && ch != 9 && ch != 10 && ch != 13) || ch >= 127 ) {
-                    yywarning_token( cif_cc, "unallowed symbol in CIF comment",
-                                     cif_flex_current_line_number(), pos, ex );
+                    if( cif_lexer_has_flags
+                        (CIF_FLEX_LEXER_FIX_NON_ASCII_SYMBOLS) ) {
+                            yynote_token( cif_cc, "unallowed symbol in CIF comment "
+                                                  "was encountered and ignored",
+                                          cif_flex_current_line_number(), pos, ex );
+                    } else {
+                        yywarning_token( cif_cc, "unallowed symbol in CIF comment",
+                                         cif_flex_current_line_number(), pos, ex );
+                    }
                 }
             }
             if( ch == '\r' ) {
@@ -270,7 +275,6 @@ static int cif_lexer( FILE *in, cexception_t *ex )
                         if( ch == EOF || isspace(ch) ) {
                             /* The quoted string is properly terminated: */
                             ungetlinec( ch, in );
-                            prevchar = token[pos-1];
                             pushchar( &token, &length, pos, '\0' );
                             ciflval.s = check_and_clean
                                 ( token, /* is_textfield = */ 0, ex );
@@ -497,7 +501,7 @@ static void pushchar( char **buf, size_t *length, size_t pos, int ch )
         }
         *length *= 2;
         if( yy_flex_debug ) {
-            printf( ">>> reallocating lex token buffer to %d\n", *length );
+            printf( ">>> reallocating lex token buffer to %lu\n", *length );
         }
         *buf = reallocx( *buf, *length, NULL );
     }
