@@ -1,15 +1,15 @@
 /*---------------------------------------------------------------------------*\
 **$Author: andrius $
-**$Date: 2017-04-12 13:39:05 +0300 (Wed, 12 Apr 2017) $ 
-**$Revision: 5195 $
-**$URL: svn://www.crystallography.net/cod-tools/tags/v2.1/src/components/codcif/cif_lexer.h $
+**$Date: 2017-11-07 11:53:10 +0200 (Tue, 07 Nov 2017) $ 
+**$Revision: 5724 $
+**$URL: svn://www.crystallography.net/cod-tools/tags/v2.2/src/components/codcif/cif_lexer.h $
 \*---------------------------------------------------------------------------*/
 
 #ifndef __CIF_LEXER_H
 #define __CIF_LEXER_H
 
 #include <stdio.h>
-#include <stdlib.h> /* for ssize_t */
+#include <unistd.h> /* for ssize_t */
 #include <cexceptions.h>
 #include <cif_compiler.h>
 
