@@ -1,14 +1,15 @@
 /*---------------------------------------------------------------------------*\
 **$Author: andrius $
-**$Date: 2017-04-12 13:39:05 +0300 (Wed, 12 Apr 2017) $ 
-**$Revision: 5195 $
-**$URL: svn://www.crystallography.net/cod-tools/tags/v2.1/src/components/codcif/common.h $
+**$Date: 2017-12-27 14:47:34 +0200 (Wed, 27 Dec 2017) $ 
+**$Revision: 5899 $
+**$URL: svn://www.crystallography.net/cod-tools/tags/v2.2/src/components/codcif/common.h $
 \*---------------------------------------------------------------------------*/
 
 #ifndef __COMMON_H
 #define __COMMON_H
 
-#include <stdlib.h>
+#include <unistd.h>
+#include <math.h>
 
 char *strclone( const char *s );
 char *strnclone( const char *s, size_t length );
@@ -28,4 +29,6 @@ int is_tag_value_unknown( char *tv );
 void fprintf_escaped( const char *message,
                       int escape_parenthesis, int escape_space );
 
+double unpack_precision( char * value, double precision );
+
 #endif
