@@ -1,8 +1,8 @@
 #------------------------------------------------------------------------------
-#$Author: antanas $
-#$Date: 2017-07-20 13:13:16 +0300 (Thu, 20 Jul 2017) $
-#$Revision: 5477 $
-#$URL: svn://www.crystallography.net/cod-tools/tags/v2.1/src/lib/perl5/COD/CIF/Data/CODPredepositionCheck.pm $
+#$Author: andrius $
+#$Date: 2018-03-01 10:37:33 +0200 (Thu, 01 Mar 2018) $
+#$Revision: 6019 $
+#$URL: svn://www.crystallography.net/cod-tools/tags/v2.2/src/lib/perl5/COD/CIF/Data/CODPredepositionCheck.pm $
 #------------------------------------------------------------------------------
 #*
 #  Filter and check pairs of CIF and Fobs files for suitability for
@@ -1396,35 +1396,4 @@ sub get_deposition_authors
     return $deposition_authors;
 }
 
-sub comm_array
-{
-    my( $arr1, $arr2 ) = @_;
-    my @arr1 = @{$arr1};
-    my @arr2 = @{$arr2};
-    my @comm;
-    while( scalar( @arr1 ) + scalar( @arr2 ) > 0 ) {
-        if( @arr1 == 0 ) {
-            push @comm, [ undef, undef, shift @arr2 ];
-            next;
-        }
-        if( @arr2 == 0 ) {
-            push @comm, [ shift @arr1, undef, undef ];
-            next;
-        }
-        if( $arr1[0] ne $arr2[0] ) {
-            if( $arr1[0] lt $arr2[0] ) {
-                push @comm, [ shift @arr1, undef, undef ];
-            } else {
-                push @comm, [ undef, undef, shift @arr2 ];
-            }
-        } else {
-            push @comm, [ undef, $arr1[0], undef ];
-            shift @arr1;
-            shift @arr2;
-        }
-        next;
-    }
-    return \@comm;
-}
-
 1;
