@@ -6,10 +6,10 @@ INPUT_MODULES='src/lib/perl5/COD/CIF/Tags/Print.pm'
 
 perl <<'END_SCRIPT'
 #------------------------------------------------------------------------------
-#$Author: andrius $
-#$Date: 2017-10-25 17:54:33 +0300 (Wed, 25 Oct 2017) $ 
-#$Revision: 5655 $
-#$URL: svn://www.crystallography.net/cod-tools/tags/v2.1/tests/shtests/cif_print_loop_001.sh $
+#$Author: antanas $
+#$Date: 2017-10-16 20:09:01 +0300 (Mon, 16 Oct 2017) $ 
+#$Revision: 5621 $
+#$URL: svn://www.crystallography.net/cod-tools/tags/v2.2/tests/shtests/cif_print_loop_001.sh $
 #------------------------------------------------------------------------------
 #*
 #  Unit test for the COD::CIF::Tags::Print::print_loop() subroutine.
@@ -37,6 +37,6 @@ my $data_block =
    }
 };
 
-COD::CIF::Tags::Print::print_loop( '_a', 0, $data_block );
+COD::CIF::Tags::Print::print_loop( $data_block, 0 );
 
 END_SCRIPT
