@@ -7,9 +7,9 @@ INPUT_MODULES='src/lib/perl5/COD/CIF/Tags/Print.pm'
 perl <<'END_SCRIPT'
 #------------------------------------------------------------------------------
 #$Author: andrius $
-#$Date: 2017-10-26 10:16:10 +0300 (Thu, 26 Oct 2017) $ 
-#$Revision: 5666 $
-#$URL: svn://www.crystallography.net/cod-tools/tags/v2.1/tests/shtests/cif_print_loop_002.sh $
+#$Date: 2017-10-26 09:27:08 +0300 (Thu, 26 Oct 2017) $ 
+#$Revision: 5664 $
+#$URL: svn://www.crystallography.net/cod-tools/tags/v2.2/tests/shtests/cif_print_loop_002.sh $
 #------------------------------------------------------------------------------
 #*
 #  Unit test for the COD::CIF::Tags::Print::print_loop() subroutine.
@@ -42,7 +42,7 @@ my $data_block =
    }
 };
 
-COD::CIF::Tags::Print::print_loop( '_a', 0, $data_block );
-COD::CIF::Tags::Print::print_loop( '_d', 1, $data_block );
+COD::CIF::Tags::Print::print_loop( $data_block, 0 );
+COD::CIF::Tags::Print::print_loop( $data_block, 1 );
 
 END_SCRIPT
